@@ -4,7 +4,7 @@ from aiohttp import web
 
 
 async def hello(request):
-    return web.Response(text="Hello, world")
+    return web.Response(text='Hello, world')
 
 
 app = web.Application()
@@ -16,5 +16,6 @@ if __name__ == '__main__':
     config_path = os.path.join(working_dir, 'conf/test.yaml')
 
     from swagger_ui import api_doc
+
     api_doc(app, config_path=config_path)
     web.run_app(app, port=8989)
